# data.gouv.fr MCP Server

Basic MCP server which returns datasets for a given query

## installation

1. Enable direnv:

```commandline
direnv allow .
```

2. Install dependencies:
```commandline
pip install .
```
